@@ -93,7 +93,7 @@ static const gnomeuiinfo_map_t gnome_uiinfo_mapping[] = {
     { "UNDO_ITEM", GNOMEUIINFO_MENU_UNDO_ITEM(NULL, NULL) },
     { "UNDO_MOVE_ITEM", GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(NULL, NULL) },
     { "VIEW_TREE", GNOMEUIINFO_MENU_VIEW_TREE(tmptree) },
-    { "WINDOWS_TREE", GNOMEUIINFO_MENU_WINDOWS_TREE(tmptree) },
+    { "WINDOWS_TREE", GNOMEUIINFO_MENU_WINDOWS_TREE(tmptree) }
 };
 
 static int
@@ -465,8 +465,6 @@ druid_page_edge_new (GladeXML *xml, GType widget_type,
     int i;
 
     const char *title, *text;
-    const char *text_color;
-    const char *logo_bg_color, *textbox_color;
     char *filename;
     GdkPixbuf *logo, *watermark, *top_watermark;
 
